@@ -55,6 +55,7 @@
 #' )
 #' @importFrom rlang .data
 RunCoxRegression_Omnibus <- function(df, time1 = "start", time2 = "end", event0 = "event", names = c("CONST"), term_n = c(0), tform = "loglin", keep_constant = c(0), a_n = c(0), modelform = "M", fir = 0, der_iden = 0, control = list(), strat_col = "null", cens_weight = "null", model_control = list(), cons_mat = as.matrix(c(0)), cons_vec = c(0)) {
+  func_t_start <- Sys.time()
   df <- data.table(df)
   ce <- c(time1, time2, event0)
   t_check <- Check_Trunc(df, ce)
@@ -73,10 +74,11 @@ RunCoxRegression_Omnibus <- function(df, time1 = "start", time2 = "end", event0
   # remove rows that start after the last event
   df <- df[get(time1) <= tu[length(tu)], ]
   control <- Def_Control(control)
+  model_control <- Def_model_control(model_control)
   val <- Correct_Formula_Order(
     term_n, tform, keep_constant, a_n,
     names, der_iden, cons_mat, cons_vec,
-    control$verbose
+    control$verbose, model_control
   )
   term_n <- val$term_n
   tform <- val$tform
@@ -86,13 +88,15 @@ RunCoxRegression_Omnibus <- function(df, time1 = "start", time2 = "end", event0
   names <- val$names
   cons_mat <- as.matrix(val$cons_mat)
   cons_vec <- val$cons_vec
+  if ("para_number" %in% names(model_control)) {
+    model_control$para_number <- val$para_num
+  }
   if (typeof(a_n) != "list") {
     a_n <- list(a_n)
   }
   if (any(val$Permutation != seq_along(tform))) {
     warning("Warning: model covariate order changed")
   }
-  model_control <- Def_model_control(model_control)
   val <- Def_modelform_fix(control, model_control, modelform, term_n)
   modelform <- val$modelform
   model_control <- val$model_control
@@ -103,6 +107,22 @@ RunCoxRegression_Omnibus <- function(df, time1 = "start", time2 = "end", event0
       df$CONST <- 1
     }
   }
+  if (model_control$linear_err == TRUE) {
+    if (all(sort(unique(tform)) != c("loglin", "plin"))) {
+      stop("Error: Linear ERR model used, but term formula wasn't only loglin and plin")
+    }
+    if (sum(tform == "plin") > 1) {
+      stop("Error: Linear ERR model used, but more than one plin element was used")
+    }
+    if (length(unique(term_n)) > 1) {
+      warning("Warning: Linear ERR model used, but more than one term number used. Term numbers all set to 0")
+      term_n <- rep(0, length(term_n))
+    }
+    if (modelform != "M") {
+      warning("Warning: Linear ERR model used, but multiplicative model not used. Modelform corrected")
+      modelform <- "M"
+    }
+  }
   if (model_control$cr == TRUE) {
     if (cens_weight %in% names(df)) {
       # good
@@ -113,7 +133,7 @@ RunCoxRegression_Omnibus <- function(df, time1 = "start", time2 = "end", event0
     df[[cens_weight]] <- 1
   }
   if (model_control$strata == FALSE) {
-    data.table::setkeyv(df, c(time2, event0))
+    data.table::setkeyv(df, c(event0, time2, time1))
     uniq <- c(0)
     ce <- c(time1, time2, event0)
   } else {
@@ -138,7 +158,7 @@ RunCoxRegression_Omnibus <- function(df, time1 = "start", time2 = "end", event0
     if (control$verbose >= 3) {
       message(paste("Note:", length(uniq), " strata used", sep = " ")) # nocov
     }
-    data.table::setkeyv(df, c(time2, event0, strat_col))
+    data.table::setkeyv(df, c(strat_col, event0, time2, time1))
     ce <- c(time1, time2, event0, strat_col)
   }
   dfend <- df[get(event0) == 1, ]
@@ -175,31 +195,14 @@ RunCoxRegression_Omnibus <- function(df, time1 = "start", time2 = "end", event0
   }
   if (model_control$log_bound) {
     if ("maxiters" %in% names(control)) {
-      if ("guesses" %in% names(control)) {
-        # both are in
-        if (control$guesses + 1 == length(control$maxiters)) {
-          # all good, it matches
-        } else if (length(control$maxiters) == 2) {
-          iter0 <- control$maxiters[1]
-          iter1 <- control$maxiters[2]
-          applied_iter <- c(rep(iter0, control$guesses), iter1)
-          control$maxiters <- applied_iter
-        } else {
-          stop(paste("Error: guesses:", control["guesses"],
-            ", iterations per guess:", control["maxiters"],
-            sep = " "
-          ))
-        }
-      } else {
-        control$guesses <- length(control$maxiters) - 1
-      }
+      # good
     } else {
-      if ("guesses" %in% names(control)) {
-        control$maxiters <- rep(1, control$guesses + 1)
-      } else {
-        control$guesses <- 1
-        control$maxiters <- c(control$maxiter)
-      }
+      control$maxiters <- c(control$maxiter)
+    }
+    if ("guesses" %in% names(control)) {
+      # good
+    } else {
+      control$guesses <- 10
     }
     e <- cox_ph_Omnibus_Bounds_transition(
       term_n, tform, a_ns,
@@ -282,8 +285,13 @@ RunCoxRegression_Omnibus <- function(df, time1 = "start", time2 = "end", event0
         stop(e$Status)
       }
     }
-    e$Parameter_Lists$names <- names
   }
+  e$Parameter_Lists$names <- names
+  e$Parameter_Lists$modelformula <- modelform
+  e$Parameter_Lists$first_term <- fir
+  e$Survival_Type <- "Cox"
+  func_t_end <- Sys.time()
+  e$RunTime <- func_t_end - func_t_start
   return(e)
 }
 
@@ -457,7 +465,7 @@ RunCoxRegression_Basic <- function(df, time1 = "start", time2 = "end", event0 =
 
 #' Performs basic Cox Proportional Hazards regression with strata effect
 #'
-#' \code{RunCoxRegression_STRATA} uses user provided data,
+#' \code{RunCoxRegression_Strata} uses user provided data,
 #' time/event columns, vectors specifying the model, and options to control
 #' the convergence and starting positions
 #'
@@ -498,13 +506,13 @@ RunCoxRegression_Basic <- function(df, time1 = "start", time2 = "end", event0 =
 #'   "verbose" = FALSE, "ties" = "breslow", "double_step" = 1
 #' )
 #' strat_col <- "e"
-#' e <- RunCoxRegression_STRATA(
+#' e <- RunCoxRegression_Strata(
 #'   df, time1, time2, event, names, term_n,
 #'   tform, keep_constant, a_n, modelform,
 #'   fir, der_iden, control, strat_col
 #' )
 #'
-RunCoxRegression_STRATA <- function(df, time1 = "start", time2 = "end", event0 = "event", names = c("CONST"), term_n = c(0), tform = "loglin", keep_constant = c(0), a_n = c(0), modelform = "M", fir = 0, der_iden = 0, control = list(), strat_col = "null") {
+RunCoxRegression_Strata <- function(df, time1 = "start", time2 = "end", event0 = "event", names = c("CONST"), term_n = c(0), tform = "loglin", keep_constant = c(0), a_n = c(0), modelform = "M", fir = 0, der_iden = 0, control = list(), strat_col = "null") {
   control <- Def_Control(control)
   control$maxiters <- c(1, control$maxiter)
   control$guesses <- 1
@@ -645,7 +653,7 @@ RunCoxNull <- function(df, time1 = "start", time2 = "end", event0 = "event", con
 #'
 #' @inheritParams R_template
 #'
-#' @return saves the plots in the current directory and returns a string
+#' @return saves the plots in the current directory and returns the data used for plots
 #' @export
 #' @family Plotting Wrapper Functions
 #' @examples
@@ -711,7 +719,13 @@ RunCoxPlots <- function(df, time1 = "start", time2 = "end", event0 = "event", na
       df$CONST <- 1
     }
   }
-  data.table::setkeyv(df, c(time2, event0))
+  ce <- c(time1, time2, event0)
+  t_check <- Check_Trunc(df, ce)
+  df <- t_check$df
+  ce <- t_check$ce
+  time1 <- ce[1]
+  time2 <- ce[2]
+  data.table::setkeyv(df, c(event0, time2, time1))
   base <- NULL
   der_iden <- 0
   plot_type <- plot_options$type
@@ -762,7 +776,7 @@ RunCoxPlots <- function(df, time1 = "start", time2 = "end", event0 = "event", na
             # fine
           } else {
             stop("Error: Covariate column " +
-                 dose_col + " is not in the dataframe")
+              dose_col + " is not in the dataframe")
           }
         }
       } else {
@@ -980,6 +994,7 @@ RunCoxPlots <- function(df, time1 = "start", time2 = "end", event0 = "event", na
 #'   "loglin_method" = "uniform", strata = TRUE, term_initial = c(0, 1)
 #' )
 #' strat_col <- "e"
+#' options(warn = -1)
 #' e <- RunCoxRegression_Tier_Guesses(
 #'   df, time1, time2, event, names,
 #'   term_n, tform, keep_constant,
@@ -1179,6 +1194,7 @@ RunCoxRegression_CR <- function(df, time1 = "start", time2 = "end", event0 = "ev
 #'   "loglin_method" = "uniform", strata = FALSE
 #' )
 #' strat_col <- "e"
+#' options(warn = -1)
 #' e <- RunCoxRegression_Guesses_CPP(
 #'   df, time1, time2, event, names, term_n,
 #'   tform, keep_constant, a_n, modelform, fir,
@@ -1321,6 +1337,7 @@ RunCoxRegression_Guesses_CPP <- function(df, time1 = "start", time2 = "end", eve
 #' )
 #' @importFrom rlang .data
 RunCoxRegression_Omnibus_Multidose <- function(df, time1 = "start", time2 = "end", event0 = "event", names = c("CONST"), term_n = c(0), tform = "loglin", keep_constant = c(0), a_n = c(0), modelform = "M", fir = 0, der_iden = 0, realization_columns = matrix(c("temp00", "temp01", "temp10", "temp11"), nrow = 2), realization_index = c("temp0", "temp1"), control = list(), strat_col = "null", cens_weight = "null", model_control = list(), cons_mat = as.matrix(c(0)), cons_vec = c(0)) {
+  func_t_start <- Sys.time()
   df <- data.table(df)
   #
   control <- Def_Control(control)
@@ -1365,8 +1382,13 @@ RunCoxRegression_Omnibus_Multidose <- function(df, time1 = "start", time2 = "end
   } else {
     df[[cens_weight]] <- 1
   }
+  if ("MCML" %in% names(model_control)) {
+    # fine
+  } else {
+    model_control$MCML <- FALSE
+  }
   if (model_control$strata == FALSE) {
-    data.table::setkeyv(df, c(time2, event0))
+    data.table::setkeyv(df, c(event0, time2, time1))
     uniq <- c(0)
     ce <- c(time1, time2, event0)
   } else {
@@ -1393,7 +1415,7 @@ RunCoxRegression_Omnibus_Multidose <- function(df, time1 = "start", time2 = "end
         sep = " "
       )) # nocov
     }
-    data.table::setkeyv(df, c(time2, event0, strat_col))
+    data.table::setkeyv(df, c(strat_col, event0, time2, time1))
     ce <- c(time1, time2, event0, strat_col)
   }
   dfend <- df[get(event0) == 1, ]
@@ -1451,5 +1473,241 @@ RunCoxRegression_Omnibus_Multidose <- function(df, time1 = "start", time2 = "end
     }
   }
   e$Parameter_Lists$names <- names
+  e$Parameter_Lists$modelformula <- modelform
+  e$Parameter_Lists$first_term <- fir
+  e$Survival_Type <- "Cox_Multidose"
+
+  func_t_end <- Sys.time()
+  e$RunTime <- func_t_end - func_t_start
+  return(e)
+}
+
+#' Calculates the likelihood curve for a cox model directly
+#'
+#' \code{CoxCurveSolver} solves the confidence interval for a cox model, starting at the optimum point and
+#' iteratively optimizing end-points of intervals. Intervals updated using the bisection method.
+#'
+#' @inheritParams R_template
+#'
+#' @return returns a list of the final results
+#' @export
+#' @family Cox Wrapper Functions
+#' @importFrom rlang .data
+CoxCurveSolver <- function(df, time1 = "start", time2 = "end", event0 = "event", names = c("CONST"), term_n = c(0), tform = "loglin", keep_constant = c(0), a_n = c(0), modelform = "M", fir = 0, der_iden = 0, control = list(), strat_col = "null", cens_weight = "null", model_control = list(), cons_mat = as.matrix(c(0)), cons_vec = c(0)) {
+  func_t_start <- Sys.time()
+  df <- data.table(df)
+  ce <- c(time1, time2, event0)
+  t_check <- Check_Trunc(df, ce)
+  df <- t_check$df
+  ce <- t_check$ce
+  ## Cox regression only uses intervals which contain an event time
+  time1 <- ce[1]
+  time2 <- ce[2]
+  dfend <- df[get(event0) == 1, ]
+  tu <- sort(unlist(unique(dfend[, time2, with = FALSE]), use.names = FALSE))
+  if (length(tu) == 0) {
+    stop("Error: no events")
+  }
+  # remove rows that end before first event
+  df <- df[get(time2) >= tu[1], ]
+  # remove rows that start after the last event
+  df <- df[get(time1) <= tu[length(tu)], ]
+  control <- Def_Control(control)
+  model_control$log_bound <- TRUE
+  model_control <- Def_model_control(model_control)
+  val <- Correct_Formula_Order(
+    term_n, tform, keep_constant, a_n,
+    names, der_iden, cons_mat, cons_vec,
+    control$verbose, model_control
+  )
+  term_n <- val$term_n
+  tform <- val$tform
+  keep_constant <- val$keep_constant
+  a_n <- val$a_n
+  der_iden <- val$der_iden
+  names <- val$names
+  cons_mat <- as.matrix(val$cons_mat)
+  cons_vec <- val$cons_vec
+  if ("para_number" %in% names(model_control)) {
+    model_control$para_number <- val$para_num
+  }
+  if (typeof(a_n) != "list") {
+    a_n <- list(a_n)
+  }
+  if (any(val$Permutation != seq_along(tform))) {
+    warning("Warning: model covariate order changed")
+  }
+  val <- Def_modelform_fix(control, model_control, modelform, term_n)
+  modelform <- val$modelform
+  model_control <- val$model_control
+  if ("CONST" %in% names) {
+    if ("CONST" %in% names(df)) {
+      # fine
+    } else {
+      df$CONST <- 1
+    }
+  }
+  if (model_control$linear_err == TRUE) {
+    if (all(sort(unique(tform)) != c("loglin", "plin"))) {
+      stop("Error: Linear ERR model used, but term formula wasn't only loglin and plin")
+    }
+    if (sum(tform == "plin") > 1) {
+      stop("Error: Linear ERR model used, but more than one plin element was used")
+    }
+    if (length(unique(term_n)) > 1) {
+      warning("Warning: Linear ERR model used, but more than one term number used. Term numbers all set to 0")
+      term_n <- rep(0, length(term_n))
+    }
+    if (modelform != "M") {
+      warning("Warning: Linear ERR model used, but multiplicative model not used. Modelform corrected")
+      modelform <- "M"
+    }
+  }
+  if (model_control$cr == TRUE) {
+    if (cens_weight %in% names(df)) {
+      # good
+    } else {
+      stop("Error: censoring weight column not in the dataframe.")
+    }
+  } else {
+    df[[cens_weight]] <- 1
+  }
+  if (model_control$strata == FALSE) {
+    data.table::setkeyv(df, c(event0, time2, time1))
+    uniq <- c(0)
+    ce <- c(time1, time2, event0)
+  } else {
+    dfend <- df[get(event0) == 1, ]
+    uniq <- sort(unlist(unique(df[, strat_col, with = FALSE]),
+      use.names = FALSE
+    ))
+    for (i in seq_along(uniq)) {
+      df0 <- dfend[get(strat_col) == uniq[i], ]
+      tu0 <- unlist(unique(df0[, time2, with = FALSE]), use.names = FALSE)
+      if (length(tu0) == 0) {
+        warning(paste("Warning: no events for strata group:",
+          uniq[i],
+          sep = " "
+        ))
+        df <- df[get(strat_col) != uniq[i], ]
+      }
+    }
+    uniq <- sort(unlist(unique(df[, strat_col, with = FALSE]),
+      use.names = FALSE
+    ))
+    if (control$verbose >= 3) {
+      message(paste("Note:", length(uniq), " strata used", sep = " ")) # nocov
+    }
+    data.table::setkeyv(df, c(strat_col, event0, time2, time1))
+    ce <- c(time1, time2, event0, strat_col)
+  }
+  dfend <- df[get(event0) == 1, ]
+  tu <- sort(unlist(unique(dfend[, time2, with = FALSE]), use.names = FALSE))
+  if (control$verbose >= 3) {
+    message(paste("Note: ", length(tu), " risk groups", sep = "")) # nocov
+  }
+  all_names <- unique(names)
+  df <- Replace_Missing(df, all_names, 0.0, control$verbose)
+  # make sure any constant 0 columns are constant
+  for (i in seq_along(keep_constant)) {
+    if ((keep_constant[i] == 0) && (names[i] %in% names(df))) {
+      if (names[i] != "CONST") {
+        if (min(df[[names[i]]]) == max(df[[names[i]]])) {
+          keep_constant[i] <- 1
+          warning(paste("Warning: element ", i,
+            " with column name ", names[i],
+            " was set constant",
+            sep = ""
+          ))
+        }
+      }
+    }
+  }
+  if (min(keep_constant) > 0) {
+    stop("Error: Atleast one parameter must be free")
+  }
+  dfc <- match(names, all_names)
+  term_tot <- max(term_n) + 1
+  x_all <- as.matrix(df[, all_names, with = FALSE])
+  a_ns <- c()
+  for (i in a_n) {
+    a_ns <- c(a_ns, i)
+  }
+  if ("maxiters" %in% names(control)) {
+    if (length(control$maxiters) == length(a_n) + 1) {
+      # all good, it matches
+    } else {
+      if (control$verbose >= 3) {
+        message(paste("Note: Initial starts:", length(a_n),
+          ", Number of iterations provided:",
+          length(control$maxiters),
+          ". Colossus requires one more iteration counts than number of guesses (for best guess)",
+          sep = " "
+        )) # nocov
+      }
+      if (length(control$maxiters) < length(a_n) + 1) {
+        additional <- length(a_n) + 1 - length(control$maxiters)
+        control$maxiters <- c(control$maxiters, rep(1, additional))
+      } else {
+        additional <- length(a_n) + 1
+        control$maxiters <- control$maxiters[1:additional]
+      }
+    }
+    if ("guesses" %in% names(control)) {
+      # both are in
+      if (control$guesses + 1 == length(control$maxiters)) {
+        # all good, it matches
+      } else if (length(control$maxiters) == 2) {
+        iter0 <- control$maxiters[1]
+        iter1 <- control$maxiters[2]
+        applied_iter <- c(rep(iter0, control$guesses), iter1)
+        control$maxiters <- applied_iter
+      } else {
+        stop(paste("Error: guesses:", control["guesses"],
+          ", iterations per guess:", control["maxiters"],
+          sep = " "
+        ))
+      }
+    } else {
+      control$guesses <- length(control$maxiters) - 1
+    }
+  } else {
+    if ("guesses" %in% names(control)) {
+      if (control$guesses == length(a_n)) {
+        # both match, all good
+      } else {
+        control$guesses <- length(a_n)
+      }
+      control$maxiters <- rep(1, control$guesses + 1)
+    } else {
+      control$guesses <- length(a_n)
+      control$maxiters <- c(rep(1, length(a_n)), control$maxiter)
+    }
+  }
+  if ("alpha" %in% names(model_control)) {
+    model_control["qchi"] <- qchisq(1 - model_control[["alpha"]], df = 1) / 2
+  } else {
+    model_control["alpha"] <- 0.05
+    model_control["qchi"] <- qchisq(1 - model_control[["alpha"]], df = 1) / 2
+  }
+  a_ns <- matrix(a_ns, nrow = length(control$maxiters) - 1, byrow = TRUE)
+  para_num <- model_control$para_num + 1 # 3
+  keep_constant[para_num] <- 1
+  if (min(keep_constant) == 1) {
+    model_control["single"] <- TRUE
+  }
+  e <- cox_ph_Omnibus_CurveSearch_transition(
+    term_n, tform, a_ns,
+    dfc, x_all, fir,
+    modelform, control, as.matrix(df[, ce, with = FALSE]), tu,
+    keep_constant, term_tot, uniq, df[[cens_weight]], model_control,
+    cons_mat, cons_vec
+  )
+  e$Parameter_Lists$names <- names
+  e$Parameter_Lists$modelformula <- modelform
+  e$Parameter_Lists$first_term <- fir
+  e$Survival_Type <- "Cox"
+  func_t_end <- Sys.time()
+  e$RunTime <- func_t_end - func_t_start
   return(e)
 }
