@@ -9,57 +9,67 @@ library(Colossus)
 library(data.table)
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  Strat_Col <- "e"
-#  e <- RunCoxRegression_STRATA(
-#    df, time1, time2, event, names, term_n, tform, keep_constant,
-#    a_n, modelform, fir, der_iden, control, Strat_Col
-#  )
+# Strat_Col <- "e"
+# e <- RunCoxRegression_Strata(
+#   df, time1, time2, event, names, term_n, tform, keep_constant,
+#   a_n, modelform,
+#   control = control, strat_col = Strat_Col
+# )
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  Strat_Col <- c("e")
-#  e <- RunPoissonRegression_STRATA(
-#    df, pyr, event, names, term_n, tform, keep_constant,
-#    a_n, modelform, fir, der_iden, control, Strat_Col
-#  )
+# Strat_Col <- c("e")
+# e <- RunPoissonRegression_Strata(
+#   df, pyr, event, names, term_n, tform, keep_constant,
+#   a_n, modelform,
+#   control = control, strat_col = Strat_Col
+# )
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  e <- RunCoxRegression_Basic(
-#    df, time1, time2, event, names,
-#    keep_constant, a_n, der_iden, control
-#  )
+# e <- RunCoxRegression_Basic(
+#   df, time1, time2, event, names,
+#   keep_constant, a_n,
+#   control = control
+# )
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  e <- RunCoxRegression_Single(
-#    df, time1, time2, event, names, term_n, tform,
-#    a_n, modelform, fir, control
-#  )
-#  
-#  e <- RunPoissonRegression_Single(
-#    df, pyr, event, names, term_n, tform,
-#    a_n, modelform, fir, control
-#  )
+# e <- RunCoxRegression_Single(
+#   df, time1, time2, event, names, term_n, tform,
+#   a_n, modelform,
+#   control = control
+# )
+# 
+# e <- RunPoissonRegression_Single(
+#   df, pyr, event, names, term_n, tform,
+#   a_n, modelform,
+#   control = control
+# )
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  df$censor <- (df$lung == 0) # censoring column made
-#  event <- "censor" # event type switched to censoring
-#  
-#  plot_options <- list("name" = "run_2", "verbose" = FALSE, "studyID" = "studyID", "age_unit" = "years")
-#  # modified plotting function used to get censoring weights
-#  dft <- GetCensWeight(
-#    df, time1, time2, event, names, term_n, tform, keep_constant,
-#    a_n, modelform, fir, control, plot_options
-#  ) # generates a survival curve
-#  t_ref <- dft$t
-#  surv_ref <- dft$surv
-#  t_c <- df$t1
-#  cens_weight <- approx(t_ref, surv_ref, t_c, rule = 2)$y
-#  # the surviving proportions used as censoring weight
-#  event <- "lung" # event switched back
-#  
-#  e <- RunCoxRegression_CR(
-#    df, time1, time2, event, names, term_n, tform, keep_constant,
-#    a_n, modelform, fir, der_iden, control, cens_weight
-#  )
+# df$censor <- (df$lung == 0) # censoring column made
+# event <- "censor" # event type switched to censoring
+# 
+# plot_options <- list(
+#   "name" = "run_2", "verbose" = FALSE,
+#   "studyID" = "studyID", "age_unit" = "years"
+# )
+# # modified plotting function used to get censoring weights
+# dft <- GetCensWeight(
+#   df, time1, time2, event, names, term_n, tform, keep_constant,
+#   a_n, modelform,
+#   control = control, plot_options = plot_options
+# ) # generates a survival curve
+# t_ref <- dft$t
+# surv_ref <- dft$surv
+# t_c <- df$t1
+# cens_weight <- approx(t_ref, surv_ref, t_c, rule = 2)$y
+# # the surviving proportions used as censoring weight
+# event <- "lung" # event switched back
+# 
+# e <- RunCoxRegression_CR(
+#   df, time1, time2, event, names, term_n, tform, keep_constant,
+#   a_n, modelform,
+#   control = control, cens_weight = cens_weight
+# )
 
 ## ----eval=TRUE----------------------------------------------------------------
 a <- c(0, 0, 0, 1, 1, 1)
@@ -120,22 +130,24 @@ guesses_control <- list(
   strata = FALSE
 )
 Strat_Col <- "f"
-RunPoissonRegression_Joint_Omnibus(
+e <- RunPoissonRegression_Joint_Omnibus(
   df, pyr, events, name_list, term_n_list,
   tform_list, keep_constant_list, a_n_list,
-  modelform, fir, der_iden, control, Strat_Col
+  modelform,
+  control = control, strat_col = Strat_Col
 )
+Interpret_Output(e)
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  a_n <- list(c(1, 1, 1), c(1, 2, 1), c(1, 2, 2), c(2, 1, 1))
-#  
-#  control$maxiter <- 5 # runs each (4) starts 1 iteration, and then runs the best 5 iterations
-#  control$maxiters <- c(1, 1, 1, 1, 5) # runs each (4) starts 1 iteration, and then runs the best 5 iterations
-#  control$maxiters <- c(5, 5, 5, 5, 5) # runs each (4) starts 5 iterations, and then runs the best 5 iterations
-#  
-#  e <- RunCoxRegression_Omnibus(df, time1, time2, event,
-#    names, term_n, tform, keep_constant,
-#    a_n, modelform,
-#    control = control
-#  )
+# a_n <- list(c(1, 1, 1), c(1, 2, 1), c(1, 2, 2), c(2, 1, 1))
+# 
+# control$maxiter <- 5 # runs each (4) starts 1 iteration, and then runs the best 5 iterations
+# control$maxiters <- c(1, 1, 1, 1, 5) # runs each (4) starts 1 iteration, and then runs the best 5 iterations
+# control$maxiters <- c(5, 5, 5, 5, 5) # runs each (4) starts 5 iterations, and then runs the best 5 iterations
+# 
+# e <- RunCoxRegression_Omnibus(df, time1, time2, event,
+#   names, term_n, tform, keep_constant,
+#   a_n, modelform,
+#   control = control
+# )
 
