@@ -50,7 +50,7 @@ struct lambda_as_visitor_wrapper : Func {
 //' @noRd
 //'
 // [[Rcpp::export]]
-void Intercept_Bound(const int& nthreads, const int& totalnum, const VectorXd& beta_0, vector<double>& dbeta, const IntegerVector& dfc, const  MatrixXd& df0, const IntegerVector& KeepConstant, bool debugging, const StringVector&  tform) {
+void Intercept_Bound(const int& nthreads, const int& totalnum, const VectorXd& beta_0, vector<double>& dbeta, const IntegerVector& dfc, const  MatrixXd& df0, const IntegerVector& KeepConstant, const StringVector&  tform) {
     set<string> Dose_Iden;  // list of dose subterms
     Dose_Iden.insert("lin_int");
     Dose_Iden.insert("step_int");
@@ -84,7 +84,7 @@ void Intercept_Bound(const int& nthreads, const int& totalnum, const VectorXd& b
 //' @noRd
 //'
 // [[Rcpp::export]]
-void Calc_Change_Cons(const MatrixXd& Lin_Sys, const VectorXd& Lin_Res, const  VectorXd& beta_0, const int& nthreads, const int& totalnum, const int& der_iden, const double& dose_abs_max, const double& lr, const double& abs_max, const vector<double>& Ll, const vector<double>& Lld, const vector<double>& Lldd, vector<double>& dbeta, const StringVector&   tform, const double& dint, const double& dslp, IntegerVector KeepConstant, bool debugging) {
+void Calc_Change_Cons(const MatrixXd& Lin_Sys, const VectorXd& Lin_Res, const  VectorXd& beta_0, const int& nthreads, const int& totalnum, const int& der_iden, const double& dose_abs_max, const double& lr, const double& abs_max, const vector<double>& Ll, const vector<double>& Lld, const vector<double>& Lldd, vector<double>& dbeta, const StringVector&   tform, const double& dint, const double& dslp, IntegerVector KeepConstant) {
     //
     int kept_covs = totalnum - sum(KeepConstant);
     //
@@ -188,7 +188,7 @@ void Calc_Change_Cons(const MatrixXd& Lin_Sys, const VectorXd& Lin_Res, const  V
 //' @noRd
 //'
 // [[Rcpp::export]]
-void Calc_Change(const int& double_step, const int& nthreads, const int& totalnum, const int& der_iden, const double& dose_abs_max, const double& lr, const double& abs_max, const vector<double>& Ll, const vector<double>& Lld, const vector<double>& Lldd, vector<double>& dbeta, const bool change_all, const StringVector&   tform, const double& dint, const double& dslp, IntegerVector KeepConstant, bool debugging) {
+void Calc_Change(const int& double_step, const int& nthreads, const int& totalnum, const int& der_iden, const double& dose_abs_max, const double& lr, const double& abs_max, const vector<double>& Ll, const vector<double>& Lld, const vector<double>& Lldd, vector<double>& dbeta, const bool change_all, const StringVector&   tform, const double& dint, const double& dslp, IntegerVector KeepConstant) {
     if (double_step == 1) {
         int kept_covs = totalnum - sum(KeepConstant);
         NumericVector Lldd_vec(kept_covs * kept_covs);
@@ -311,6 +311,100 @@ void Calc_Change(const int& double_step, const int& nthreads, const int& totalnu
     return;
 }
 
+//' Utility function to calculate the change to make each iteration with gradient step
+//'
+//' \code{Calc_Change_Gradient} Called to update the parameter changes, Uses log-likelihoods and control parameters, Applies gradient normalization and change limitations
+//' @inheritParams CPP_template
+//'
+//' @return Updates matrices in place: parameter change matrix
+//' @noRd
+//'
+// [[Rcpp::export]]
+void Calc_Change_Gradient(const int& nthreads, List& model_bool, const int& totalnum, List& optim_para, int& iteration, const double& abs_max, const vector<double>& Lld, NumericVector& m_g_store, NumericVector& v_beta_store, vector<double>& dbeta, IntegerVector KeepConstant) {
+    int kept_covs = totalnum - sum(KeepConstant);
+    NumericVector Lld_vec(kept_covs);
+    for (int ij = 0; ij < kept_covs; ij++) {
+        Lld_vec[ij] = Lld[ij];
+    }
+    //
+    // Written for the sake of preparing what variables will be needed
+    bool momentum_bool = model_bool["momentum"]; //assumed I will define booleans to pick which one is used
+    bool adadelta_bool = model_bool["adadelta"];
+    bool adam_bool     = model_bool["adam"];
+    // grouped the necessary variables
+    double lr = optim_para["lr"];
+    double decay1 = optim_para["momentum_decay"];
+    double decay2 = optim_para["learning_decay"];
+    double epsilon_momentum = optim_para["epsilon_decay"];
+    // required vectors for storage
+    if (momentum_bool) {
+        //
+        for (int ijk = 0; ijk < totalnum; ijk++) {
+            if (KeepConstant[ijk] == 0) {
+                int pjk_ind = ijk - sum(head(KeepConstant, ijk));
+                dbeta[ijk] = decay1 * m_g_store[pjk_ind] + lr * Lld_vec[pjk_ind];  //-lr * Lld[ijk] / Lldd[ijk*totalnum+ijk];
+                m_g_store[pjk_ind] = dbeta[ijk];
+			    if (abs(dbeta[ijk]) > abs_max) {
+				    dbeta[ijk] = abs_max * sign(dbeta[ijk]);
+			    }
+            } else {
+                dbeta[ijk] = 0;
+            }
+        }
+    } else if (adadelta_bool) {
+        //
+        for (int ijk = 0; ijk < totalnum; ijk++) {
+            if (KeepConstant[ijk] == 0) {
+                int pjk_ind = ijk - sum(head(KeepConstant, ijk));
+                m_g_store[pjk_ind] = decay1 * m_g_store[pjk_ind] + (1-decay1)*pow(Lld_vec[pjk_ind],2);
+                v_beta_store[pjk_ind] = decay1 * v_beta_store[pjk_ind] + (1-decay1)*pow(dbeta[ijk],2);
+                dbeta[ijk] = pow((v_beta_store[pjk_ind] + epsilon_momentum) / (m_g_store[pjk_ind] +epsilon_momentum ),0.5)* Lld_vec[pjk_ind];  //-lr * Lld[ijk] / Lldd[ijk*totalnum+ijk];
+			    if (abs(dbeta[ijk]) > abs_max) {
+				    dbeta[ijk] = abs_max * sign(dbeta[ijk]);
+			    }
+            } else {
+                dbeta[ijk] = 0;
+            }
+        }
+    } else if (adam_bool) {
+        //
+        for (int ijk = 0; ijk < totalnum; ijk++) {
+            if (KeepConstant[ijk] == 0) {
+                int pjk_ind = ijk - sum(head(KeepConstant, ijk));
+                m_g_store[pjk_ind] = decay1 * m_g_store[pjk_ind] + (1-decay1)*Lld_vec[pjk_ind];
+                v_beta_store[pjk_ind] = decay2 * v_beta_store[pjk_ind] + (1-decay2)*pow(Lld_vec[pjk_ind],2);
+                //
+                double m_t_bias = m_g_store[pjk_ind] / (1 - pow(decay1,iteration));
+                double v_t_bias = v_beta_store[pjk_ind] / (1 - pow(decay2,iteration));
+                //
+                dbeta[ijk] = lr / (pow(v_t_bias,0.5)+epsilon_momentum) * m_t_bias;  //-lr * Lld[ijk] / Lldd[ijk*totalnum+ijk];
+			    if (abs(dbeta[ijk]) > abs_max) {
+				    dbeta[ijk] = abs_max * sign(dbeta[ijk]);
+			    }
+            } else {
+                dbeta[ijk] = 0;
+            }
+        }
+    } else {
+        //
+        #ifdef _OPENMP
+        #pragma omp parallel for schedule(dynamic) num_threads(nthreads)
+        #endif
+        for (int ijk = 0; ijk < totalnum; ijk++) {
+            if (KeepConstant[ijk] == 0) {
+                int pjk_ind = ijk - sum(head(KeepConstant, ijk));
+                dbeta[ijk] = lr * Lld_vec[pjk_ind];  //-lr * Lld[ijk] / Lldd[ijk*totalnum+ijk];
+			    if (abs(dbeta[ijk]) > abs_max) {
+				    dbeta[ijk] = abs_max * sign(dbeta[ijk]);
+			    }
+            } else {
+                dbeta[ijk] = 0;
+            }
+        }
+    }
+    return;
+}
+
 //' Utility function to calculate the change to make each iteration, with basic model
 //'
 //' \code{Calc_Change_Basic} Called to update the parameter changes, Uses log-likelihoods and control parameters, Applies newton steps and change limitations
@@ -320,7 +414,7 @@ void Calc_Change(const int& double_step, const int& nthreads, const int& totalnu
 //' @noRd
 //'
 // [[Rcpp::export]]
-void Calc_Change_Basic(const int& double_step, const int& nthreads, const int& totalnum, const int& der_iden, const double& lr, const double& abs_max, const vector<double>& Ll, const vector<double>& Lld, const vector<double>& Lldd, vector<double>& dbeta, const bool change_all, IntegerVector KeepConstant, bool debugging) {
+void Calc_Change_Basic(const int& double_step, const int& nthreads, const int& totalnum, const int& der_iden, const double& lr, const double& abs_max, const vector<double>& Ll, const vector<double>& Lld, const vector<double>& Lldd, vector<double>& dbeta, const bool change_all, IntegerVector KeepConstant) {
     if (double_step == 1) {
         //
         int kept_covs = totalnum - sum(KeepConstant);
@@ -403,11 +497,9 @@ void Calc_Change_Basic(const int& double_step, const int& nthreads, const int& t
                         dbeta[ijk] = 0;
                     }
                     //
-                    double dbeta_max;
+                    double dbeta_max = 0.0;
                     if (Lld[ijk]!=0) {
                         dbeta_max = abs(Ll[ijk]/Lld[ijk]);  // uses newtonian step for zero log-likelihood as a limit
-                    }else{
-                        dbeta_max = 0;
                     }
                     if (abs(dbeta[ijk])>dbeta_max) {
                         dbeta[ijk] = dbeta_max * sign(dbeta[ijk]);
@@ -447,14 +539,6 @@ void Log_Bound(double& deriv_max, const MatrixXd& Lldd_mat, const VectorXd& Lld_
     MatrixXd D0 = Lldd_mat;
     deriv_max = 100;
     if (step == 0) {
-        // if (verbose >= 4) {
-        //     Rcout << "C++ Note: df201 " << L0 << " " << Lstar << " " << endl;
-        //     Rcout << "C++ Note: df204 ";  // prints parameter values
-        //     for (int ij = 0; ij < totalnum; ij++) {
-        //         Rcout << beta_0[ij] << " ";
-        //     }
-        //     Rcout << " " << endl;
-        // }
         // initial step, calculate dom/dbet and h
         MatrixXd dOmdBeta = Lldd_mat.col(para_number).matrix();
         removeRow(D0, para_number);
@@ -498,25 +582,6 @@ void Log_Bound(double& deriv_max, const MatrixXd& Lldd_mat, const VectorXd& Lld_
             }
         }
         // At this point, we have the standard newton-raphson equation defined
-        // if (verbose >= 4) {
-        //     Rcout << "C++ Note: df201 " << L0 << " " << Lstar << " " << endl;
-        //     Rcout << "C++ Note: df202 ";  // prints the first derivatives
-        //     for (int ij = 0; ij < reqrdnum; ij++) {
-        //         Rcout << v[ij] << " ";
-        //     }
-        //     Rcout << " " << endl;
-        //     Rcout << "C++ Note: df203 ";  // prints the second derivatives
-        //     for (int ij = 0; ij < reqrdnum; ij++) {
-        //         Rcout << G(ij, ij) << " ";
-        //     }
-        //     Rcout << " " << endl;
-        //     Rcout << "C++ Note: df204 ";  // prints parameter values
-        //     for (int ij = 0; ij < totalnum; ij++) {
-        //         Rcout << beta_0[ij] << " ";
-        //     }
-        //     Rcout << " " << endl;
-        //     Rcout << "C++ Note: Second Derivative Determinant: " << G.determinant() << endl;
-        // }
         deriv_max = abs(v[0]);
         for (int ij = 0; ij < reqrdnum; ij++) {
             if (abs(v[ij])>deriv_max) {
@@ -535,13 +600,11 @@ void Log_Bound(double& deriv_max, const MatrixXd& Lldd_mat, const VectorXd& Lld_
         } else {
             G = G.inverse().matrix();
             v = G.matrix() * v.matrix();
-    //        Rcout << "reached G" << endl;
             VectorXd g1 = G.col(para_number);
             // we now must solve for the roots
             double as2 = g1.matrix().transpose() * D0 * g1.matrix();
             double bs1 = 2*v.matrix().transpose() *D0 * g1.matrix() - 2;
             double cs0 = v.matrix().transpose() * D0 * v.matrix();
-//            Rcout << as2 << "s^2 + " << bs1 << "s + " << cs0 << endl;
             //
             if (pow(bs1, 2)-4*as2*cs0 >= 0) {
                 double s0 = pow(bs1, 2)-4*as2*cs0;
@@ -581,13 +644,6 @@ void Log_Bound(double& deriv_max, const MatrixXd& Lldd_mat, const VectorXd& Lld_
                 }
             }
         }
-        // if (verbose >= 4) {
-        //     Rcout << "C++ Note: df205 ";  // prints parameter values
-        //     for (int ij = 0; ij < totalnum; ij++) {
-        //         Rcout << dbeta[ij] << " ";
-        //     }
-        //     Rcout << " " << endl;
-        // }
     }
     return;
 }
@@ -601,7 +657,7 @@ void Log_Bound(double& deriv_max, const MatrixXd& Lldd_mat, const VectorXd& Lld_
 //' @noRd
 //'
 // [[Rcpp::export]]
-void Calc_Change_trouble(const int& para_number, const int& nthreads, const int& totalnum, const double& dose_abs_max, const double& lr, const double& abs_max, const vector<double>& Ll, const vector<double>& Lld, const vector<double>& Lldd, vector<double>& dbeta, const StringVector&   tform, const double& dint, const double& dslp, IntegerVector KeepConstant_trouble, bool debugging) {
+void Calc_Change_trouble(const int& para_number, const int& nthreads, const int& totalnum, const double& dose_abs_max, const double& lr, const double& abs_max, const vector<double>& Ll, const vector<double>& Lld, const vector<double>& Lldd, vector<double>& dbeta, const StringVector&   tform, const double& dint, const double& dslp, IntegerVector KeepConstant_trouble) {
     int kept_covs = totalnum - sum(KeepConstant_trouble);
     NumericVector Lldd_vec(kept_covs * kept_covs);
     NumericVector Lld_vec(kept_covs);
@@ -630,8 +686,6 @@ void Calc_Change_trouble(const int& para_number, const int& nthreads, const int&
             Lldd_vec[ij * kept_covs + jk] = Lldd_vec[jk0 * (kept_covs + 1) + ij0];
         }
     }
-    //
-    //
     Lldd_vec.attr("dim") = Dimension(kept_covs, kept_covs);
     const Map<MatrixXd> Lldd_mat(as<Map<MatrixXd> >(Lldd_vec));
     const Map<VectorXd> Lld_mat(as<Map<VectorXd> >(Lld_vec));
@@ -659,7 +713,7 @@ void Calc_Change_trouble(const int& para_number, const int& nthreads, const int&
             } else {
                 dbeta[ijk] = lr * Lldd_solve(ijk);  //-lr * Lld[ijk] / Lldd[ijk*totalnum+ijk];
             }
-//            //
+           //
             if ((tform[ijk] == "lin_quad_int") || (tform[ijk] == "lin_exp_int") || (tform[ijk] == "step_int") || (tform[ijk] == "lin_int")) {  // the threshold values use different maximum deviation values
                 if (abs(dbeta[ijk]) > dose_abs_max) {
                     dbeta[ijk] = dose_abs_max * sign(dbeta[ijk]);
