@@ -20,14 +20,14 @@ test_that("Poisson residual no error", {
   # tfile <- file(paste(tempfile(), ".txt",sep="" ),open = "wt")
   # sink(file=tfile)
   control <- list("ncores" = 2, "lr" = 0.95, "maxiter" = -1, "halfmax" = 1, "epsilon" = 1e-9, "deriv_epsilon" = 1e-9, "abs_max" = 1.0, "change_all" = TRUE, "dose_abs_max" = 1.0, "verbose" = 0, "double_step" = 1)
-  model_control <- list("pearson" = F, "deviance" = F)
+  model_control <- list("pearson" = FALSE, "deviance" = FALSE)
   expect_no_error(RunPoissonRegression_Residual(df, pyr, event, names, term_n, tform, keep_constant, a_n, modelform, fir, der_iden, control, strat_col = "rand", model_control))
-  model_control <- list("pearson" = T, "deviance" = F)
+  model_control <- list("pearson" = TRUE, "deviance" = FALSE)
   expect_no_error(RunPoissonRegression_Residual(df, pyr, event, names, term_n, tform, keep_constant, a_n, modelform, fir, der_iden, control, strat_col = "rand", model_control))
-  model_control <- list("pearson" = F, "deviance" = T)
+  model_control <- list("pearson" = FALSE, "deviance" = TRUE)
   expect_no_error(RunPoissonRegression_Residual(df, pyr, event, names, term_n, tform, keep_constant, a_n, modelform, fir, der_iden, control, strat_col = "rand", model_control))
   #
-  model_control <- list("pearson" = F, "deviance" = F, "strata" = T)
+  model_control <- list("pearson" = FALSE, "deviance" = FALSE, "strata" = TRUE)
   expect_no_error(RunPoissonRegression_Residual(df, pyr, event, names, term_n, tform, keep_constant, a_n, modelform, fir, der_iden, control, strat_col = "e", model_control))
   c <- c(0, 0, 0, 0, 0, 1, 0)
   e <- c(0, 0, 0, 1, 1, 1, 1)
